@@ -1399,17 +1399,27 @@ class TestNetworkElementUpdate(unittest.TestCase):
         ponlink.poller_hash = poller_hash
         self.assertEqual(poller_hash, ponlink.poller_hash)
 
+        ponlink.errctx = network_element_update.ErrorContext()
         self.assertEqual(ponlink.rx_power, None)
-        ponlink.rx_power = 90.59
-        self.assertEqual(round(ponlink.rx_power, 4), 90.59)
+        ponlink.rx_power = -20.59
+        self.assertEqual(round(ponlink.rx_power, 4), -20.59)
+        ponlink.rx_power = 190.59
+        self.assertEqual(round(ponlink.rx_power, 4), -20.59)
         ponlink.rx_power = None
         self.assertEqual(ponlink.rx_power, None)
+        self.assertEqual(len(ponlink.errctx.errors), 1)
+        ponlink.errctx = None
 
+        ponlink.errctx = network_element_update.ErrorContext()
         self.assertEqual(ponlink.tx_power, None)
-        ponlink.tx_power = 80.59
-        self.assertEqual(round(ponlink.tx_power, 4), 80.59)
+        ponlink.tx_power = -20.59
+        self.assertEqual(round(ponlink.tx_power, 4), -20.59)
+        ponlink.tx_power = 190.59
+        self.assertEqual(round(ponlink.tx_power, 4), -20.59)
         ponlink.tx_power = None
         self.assertEqual(ponlink.tx_power, None)
+        self.assertEqual(len(ponlink.errctx.errors), 1)
+        ponlink.errctx = None
 
         ponlink.errctx = network_element_update.ErrorContext()
         self.assertEqual(ponlink.fiber_length, None)
